{
  lib,
  stdenv,
  rustPlatform,
  fetchzip,
  openssl,
  pkg-config,
  installShellFiles,
  darwin,
  bash,

  # rbw-fzf
  fzf,
  perl
}:

rustPlatform.buildRustPackage rec {
  pname = "rbw-latest";
  version = "1.13.1";

  src = fetchzip {
    url = "https://git.tozt.net/rbw/snapshot/rbw-${version}.tar.gz";
    hash = "sha256-6T1pa+LzgJLaPbWJg7imZZ6KuGJ47YqpSKXxrv4E+1I=";
  };

  cargoHash = "sha256-NGt60HJwHnP4vwQp8oHpmmTa72lHVDftFo6whu4V9JQ=";

  nativeBuildInputs = [
    installShellFiles
  ] ++ lib.optionals stdenv.hostPlatform.isLinux [ pkg-config ];

  buildInputs =
    [ bash ]; # for git-credential-rbw

  preConfigure = lib.optionalString stdenv.hostPlatform.isLinux ''
    export OPENSSL_INCLUDE_DIR="${openssl.dev}/include"
    export OPENSSL_LIB_DIR="${lib.getLib openssl}/lib"
  '';

  postInstall =
    ''
      install -Dm755 -t $out/bin bin/git-credential-rbw
      install -Dm755 -t $out/bin bin/rbw-fzf
      substituteInPlace $out/bin/rbw-fzf \
        --replace fzf ${fzf}/bin/fzf \
        --replace perl ${perl}/bin/perl
    ''
    + lib.optionalString (stdenv.buildPlatform.canExecute stdenv.hostPlatform) ''
      installShellCompletion --cmd rbw \
        --bash <($out/bin/rbw gen-completions bash) \
        --fish <($out/bin/rbw gen-completions fish) \
        --zsh <($out/bin/rbw gen-completions zsh)
    '';

  meta = with lib; {
    description = "Unofficial command line client for Bitwarden";
    homepage = "https://crates.io/crates/rbw";
    changelog = "https://git.tozt.net/rbw/plain/CHANGELOG.md?id=${version}";
    license = licenses.mit;
    mainProgram = "rbw";
  };
}
